==> haskell-hslogger-1.3.2.0-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslogger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslogger
version:              1.3.2.0
visibility:           public
id:                   hslogger-1.3.2.0-8brmtmtSRGxFCWqCWZlV0O
key:                  hslogger-1.3.2.0-8brmtmtSRGxFCWqCWZlV0O
license:              BSD-3-Clause
copyright:
    Copyright (c) 2004-2018 John Goerzen
    , (c) 2019      Herbert Valerio Riedel

maintainer:           https://github.com/haskell-hvr/hslogger
author:               John Goerzen
homepage:             https://github.com/haskell-hvr/hslogger/wiki
synopsis:             Versatile logging framework
description:
    @hslogger@ is a logging framework for Haskell, roughly similar
    to [Python'\''s logging module](https://docs.python.org/2/library/logging.html).

    @hslogger@ lets each log message have a priority and source be associated
    with it.  The programmer can then define global handlers that route
    or filter messages based on the priority and source.  @hslogger@ also
    has a [Syslog](https://tools.ietf.org/html/rfc5424) handler built in.

category:             Interfaces
abi:                  126d9bce824820cfdb7d6f8064017f01
exposed:              True
exposed-modules:
    System.Log System.Log.Formatter System.Log.Handler
    System.Log.Handler.Growl System.Log.Handler.Log4jXML
    System.Log.Handler.Simple System.Log.Handler.Syslog
    System.Log.Logger

hidden-modules:       UTF8
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslogger-1.3.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslogger-1.3.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslogger-1.3.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslogger
hs-libraries:         HShslogger-1.3.2.0-8brmtmtSRGxFCWqCWZlV0O
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    network-3.1.4.0-1n8WDlzhAQUHYfqI16mYdv
    network-bsd-2.8.1.0-9blh8PjPb8A8jGe3Fzprnu time-1.12.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-hslogger/html/hslogger.haddock
haddock-html:         /usr/share/doc/haskell-hslogger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslogger-1.3.2.0-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslogger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslogger
version:              1.3.2.0
visibility:           public
id:                   hslogger-1.3.2.0-AjTk1C0pxzs9yKeH9MMN3O
key:                  hslogger-1.3.2.0-AjTk1C0pxzs9yKeH9MMN3O
license:              BSD-3-Clause
copyright:
    Copyright (c) 2004-2018 John Goerzen
    , (c) 2019      Herbert Valerio Riedel

maintainer:           https://github.com/haskell-hvr/hslogger
author:               John Goerzen
homepage:             https://github.com/haskell-hvr/hslogger/wiki
synopsis:             Versatile logging framework
description:
    @hslogger@ is a logging framework for Haskell, roughly similar
    to [Python'\''s logging module](https://docs.python.org/2/library/logging.html).

    @hslogger@ lets each log message have a priority and source be associated
    with it.  The programmer can then define global handlers that route
    or filter messages based on the priority and source.  @hslogger@ also
    has a [Syslog](https://tools.ietf.org/html/rfc5424) handler built in.

category:             Interfaces
abi:                  ae82957c774e19c28f041f729fd89c7a
exposed:              True
exposed-modules:
    System.Log System.Log.Formatter System.Log.Handler
    System.Log.Handler.Growl System.Log.Handler.Log4jXML
    System.Log.Handler.Simple System.Log.Handler.Syslog
    System.Log.Logger

hidden-modules:       UTF8
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslogger-1.3.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslogger-1.3.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslogger-1.3.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslogger
hs-libraries:         HShslogger-1.3.2.0-AjTk1C0pxzs9yKeH9MMN3O
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    network-3.1.4.0-IC0hdE8eZqJ6PeeNglfLy3
    network-bsd-2.8.1.0-Dwchj9QAXSX7UKHrUfNcqy time-1.12.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-hslogger/html/hslogger.haddock
haddock-html:         /usr/share/doc/haskell-hslogger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
